@@ -66,7 +66,26 @@ class ContentLibrary(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ContentLibrary.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                name: builtins.str,
+                storage_backing: typing.Sequence[builtins.str],
+                description: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                publication: typing.Optional[typing.Union[ContentLibraryPublication, typing.Dict[str, typing.Any]]] = None,
+                subscription: typing.Optional[typing.Union[ContentLibrarySubscription, typing.Dict[str, typing.Any]]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ContentLibraryConfig(
@@ -214,7 +233,9 @@ class ContentLibrary(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrary, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -226,7 +247,9 @@ class ContentLibrary(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrary, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -238,7 +261,9 @@ class ContentLibrary(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrary, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -250,7 +275,9 @@ class ContentLibrary(
     @storage_backing.setter
     def storage_backing(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrary, "storage_backing").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "storageBacking", value)
 
@@ -314,7 +341,24 @@ class ContentLibraryConfig(cdktf.TerraformMetaArguments):
         if isinstance(subscription, dict):
             subscription = ContentLibrarySubscription(**subscription)
         if __debug__:
-            type_hints = typing.get_type_hints(ContentLibraryConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                name: builtins.str,
+                storage_backing: typing.Sequence[builtins.str],
+                description: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                publication: typing.Optional[typing.Union[ContentLibraryPublication, typing.Dict[str, typing.Any]]] = None,
+                subscription: typing.Optional[typing.Union[ContentLibrarySubscription, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -510,7 +554,15 @@ class ContentLibraryPublication:
         :param username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/content_library#username ContentLibrary#username}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ContentLibraryPublication.__init__)
+            def stub(
+                *,
+                authentication_method: typing.Optional[builtins.str] = None,
+                password: typing.Optional[builtins.str] = None,
+                published: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                username: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument authentication_method", value=authentication_method, expected_type=type_hints["authentication_method"])
             check_type(argname="argument password", value=password, expected_type=type_hints["password"])
             check_type(argname="argument published", value=published, expected_type=type_hints["published"])
@@ -578,7 +630,12 @@ class ContentLibraryPublicationOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ContentLibraryPublicationOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -634,7 +691,9 @@ class ContentLibraryPublicationOutputReference(
     @authentication_method.setter
     def authentication_method(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibraryPublicationOutputReference, "authentication_method").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "authenticationMethod", value)
 
@@ -646,7 +705,9 @@ class ContentLibraryPublicationOutputReference(
     @password.setter
     def password(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibraryPublicationOutputReference, "password").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -658,7 +719,9 @@ class ContentLibraryPublicationOutputReference(
     @published.setter
     def published(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibraryPublicationOutputReference, "published").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "published", value)
 
@@ -670,7 +733,9 @@ class ContentLibraryPublicationOutputReference(
     @username.setter
     def username(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibraryPublicationOutputReference, "username").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "username", value)
 
@@ -682,7 +747,9 @@ class ContentLibraryPublicationOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[ContentLibraryPublication]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibraryPublicationOutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[ContentLibraryPublication]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -719,7 +786,17 @@ class ContentLibrarySubscription:
         :param username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/content_library#username ContentLibrary#username}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ContentLibrarySubscription.__init__)
+            def stub(
+                *,
+                authentication_method: typing.Optional[builtins.str] = None,
+                automatic_sync: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                on_demand: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                password: typing.Optional[builtins.str] = None,
+                subscription_url: typing.Optional[builtins.str] = None,
+                username: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument authentication_method", value=authentication_method, expected_type=type_hints["authentication_method"])
             check_type(argname="argument automatic_sync", value=automatic_sync, expected_type=type_hints["automatic_sync"])
             check_type(argname="argument on_demand", value=on_demand, expected_type=type_hints["on_demand"])
@@ -807,7 +884,12 @@ class ContentLibrarySubscriptionOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ContentLibrarySubscriptionOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -878,7 +960,9 @@ class ContentLibrarySubscriptionOutputReference(
     @authentication_method.setter
     def authentication_method(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrarySubscriptionOutputReference, "authentication_method").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "authenticationMethod", value)
 
@@ -893,7 +977,9 @@ class ContentLibrarySubscriptionOutputReference(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrarySubscriptionOutputReference, "automatic_sync").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "automaticSync", value)
 
@@ -905,7 +991,9 @@ class ContentLibrarySubscriptionOutputReference(
     @on_demand.setter
     def on_demand(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrarySubscriptionOutputReference, "on_demand").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "onDemand", value)
 
@@ -917,7 +1005,9 @@ class ContentLibrarySubscriptionOutputReference(
     @password.setter
     def password(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrarySubscriptionOutputReference, "password").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -929,7 +1019,9 @@ class ContentLibrarySubscriptionOutputReference(
     @subscription_url.setter
     def subscription_url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrarySubscriptionOutputReference, "subscription_url").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "subscriptionUrl", value)
 
@@ -941,7 +1033,9 @@ class ContentLibrarySubscriptionOutputReference(
     @username.setter
     def username(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrarySubscriptionOutputReference, "username").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "username", value)
 
@@ -956,7 +1050,9 @@ class ContentLibrarySubscriptionOutputReference(
         value: typing.Optional[ContentLibrarySubscription],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ContentLibrarySubscriptionOutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[ContentLibrarySubscription]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
