@@ -60,7 +60,23 @@ class DataVsphereComputeClusterHostGroup(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataVsphereComputeClusterHostGroup.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                compute_cluster_id: builtins.str,
+                name: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataVsphereComputeClusterHostGroupConfig(
@@ -119,7 +135,9 @@ class DataVsphereComputeClusterHostGroup(
     @compute_cluster_id.setter
     def compute_cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereComputeClusterHostGroup, "compute_cluster_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computeClusterId", value)
 
@@ -131,7 +149,9 @@ class DataVsphereComputeClusterHostGroup(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereComputeClusterHostGroup, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -143,7 +163,9 @@ class DataVsphereComputeClusterHostGroup(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereComputeClusterHostGroup, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -194,7 +216,21 @@ class DataVsphereComputeClusterHostGroupConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataVsphereComputeClusterHostGroupConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                compute_cluster_id: builtins.str,
+                name: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
