@@ -84,7 +84,35 @@ class DataVsphereOvfVmTemplate(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataVsphereOvfVmTemplate.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                host_system_id: builtins.str,
+                name: builtins.str,
+                resource_pool_id: builtins.str,
+                allow_unverified_ssl_cert: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                datastore_id: typing.Optional[builtins.str] = None,
+                deployment_option: typing.Optional[builtins.str] = None,
+                disk_provisioning: typing.Optional[builtins.str] = None,
+                enable_hidden_properties: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                folder: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                ip_allocation_policy: typing.Optional[builtins.str] = None,
+                ip_protocol: typing.Optional[builtins.str] = None,
+                local_ovf_path: typing.Optional[builtins.str] = None,
+                ovf_network_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                remote_ovf_url: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataVsphereOvfVmTemplateConfig(
@@ -350,7 +378,9 @@ class DataVsphereOvfVmTemplate(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "allow_unverified_ssl_cert").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowUnverifiedSslCert", value)
 
@@ -362,7 +392,9 @@ class DataVsphereOvfVmTemplate(
     @datastore_id.setter
     def datastore_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "datastore_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "datastoreId", value)
 
@@ -374,7 +406,9 @@ class DataVsphereOvfVmTemplate(
     @deployment_option.setter
     def deployment_option(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "deployment_option").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "deploymentOption", value)
 
@@ -386,7 +420,9 @@ class DataVsphereOvfVmTemplate(
     @disk_provisioning.setter
     def disk_provisioning(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "disk_provisioning").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "diskProvisioning", value)
 
@@ -403,7 +439,9 @@ class DataVsphereOvfVmTemplate(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "enable_hidden_properties").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableHiddenProperties", value)
 
@@ -415,7 +453,9 @@ class DataVsphereOvfVmTemplate(
     @folder.setter
     def folder(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "folder").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "folder", value)
 
@@ -427,7 +467,9 @@ class DataVsphereOvfVmTemplate(
     @host_system_id.setter
     def host_system_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "host_system_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "hostSystemId", value)
 
@@ -439,7 +481,9 @@ class DataVsphereOvfVmTemplate(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -451,7 +495,9 @@ class DataVsphereOvfVmTemplate(
     @ip_allocation_policy.setter
     def ip_allocation_policy(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "ip_allocation_policy").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ipAllocationPolicy", value)
 
@@ -463,7 +509,9 @@ class DataVsphereOvfVmTemplate(
     @ip_protocol.setter
     def ip_protocol(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "ip_protocol").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ipProtocol", value)
 
@@ -475,7 +523,9 @@ class DataVsphereOvfVmTemplate(
     @local_ovf_path.setter
     def local_ovf_path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "local_ovf_path").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "localOvfPath", value)
 
@@ -487,7 +537,9 @@ class DataVsphereOvfVmTemplate(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -502,7 +554,9 @@ class DataVsphereOvfVmTemplate(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "ovf_network_map").fset)
+            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ovfNetworkMap", value)
 
@@ -514,7 +568,9 @@ class DataVsphereOvfVmTemplate(
     @remote_ovf_url.setter
     def remote_ovf_url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "remote_ovf_url").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "remoteOvfUrl", value)
 
@@ -526,7 +582,9 @@ class DataVsphereOvfVmTemplate(
     @resource_pool_id.setter
     def resource_pool_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataVsphereOvfVmTemplate, "resource_pool_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourcePoolId", value)
 
@@ -613,7 +671,33 @@ class DataVsphereOvfVmTemplateConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataVsphereOvfVmTemplateConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                host_system_id: builtins.str,
+                name: builtins.str,
+                resource_pool_id: builtins.str,
+                allow_unverified_ssl_cert: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                datastore_id: typing.Optional[builtins.str] = None,
+                deployment_option: typing.Optional[builtins.str] = None,
+                disk_provisioning: typing.Optional[builtins.str] = None,
+                enable_hidden_properties: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                folder: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                ip_allocation_policy: typing.Optional[builtins.str] = None,
+                ip_protocol: typing.Optional[builtins.str] = None,
+                local_ovf_path: typing.Optional[builtins.str] = None,
+                ovf_network_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                remote_ovf_url: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
