@@ -106,7 +106,46 @@ class DatastoreCluster(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DatastoreCluster.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                datacenter_id: builtins.str,
+                name: builtins.str,
+                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                folder: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                sdrs_advanced_options: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                sdrs_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_default_intra_vm_affinity: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                sdrs_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                sdrs_free_space_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_free_space_threshold_mode: typing.Optional[builtins.str] = None,
+                sdrs_free_space_utilization_difference: typing.Optional[jsii.Number] = None,
+                sdrs_io_balance_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_io_latency_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_load_balance_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                sdrs_io_load_imbalance_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_reservable_iops_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_reservable_percent_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_reservable_threshold_mode: typing.Optional[builtins.str] = None,
+                sdrs_load_balance_interval: typing.Optional[jsii.Number] = None,
+                sdrs_policy_enforcement_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_rule_enforcement_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_space_balance_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_space_utilization_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_vm_evacuation_automation_level: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DatastoreClusterConfig(
@@ -415,7 +454,9 @@ class DatastoreCluster(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "custom_attributes").fset)
+            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "customAttributes", value)
 
@@ -427,7 +468,9 @@ class DatastoreCluster(
     @datacenter_id.setter
     def datacenter_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "datacenter_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "datacenterId", value)
 
@@ -439,7 +482,9 @@ class DatastoreCluster(
     @folder.setter
     def folder(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "folder").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "folder", value)
 
@@ -451,7 +496,9 @@ class DatastoreCluster(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -463,7 +510,9 @@ class DatastoreCluster(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -478,7 +527,9 @@ class DatastoreCluster(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_advanced_options").fset)
+            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsAdvancedOptions", value)
 
@@ -490,7 +541,9 @@ class DatastoreCluster(
     @sdrs_automation_level.setter
     def sdrs_automation_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_automation_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsAutomationLevel", value)
 
@@ -507,7 +560,9 @@ class DatastoreCluster(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_default_intra_vm_affinity").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsDefaultIntraVmAffinity", value)
 
@@ -522,7 +577,9 @@ class DatastoreCluster(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_enabled").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsEnabled", value)
 
@@ -534,7 +591,9 @@ class DatastoreCluster(
     @sdrs_free_space_threshold.setter
     def sdrs_free_space_threshold(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_free_space_threshold").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsFreeSpaceThreshold", value)
 
@@ -546,7 +605,9 @@ class DatastoreCluster(
     @sdrs_free_space_threshold_mode.setter
     def sdrs_free_space_threshold_mode(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_free_space_threshold_mode").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsFreeSpaceThresholdMode", value)
 
@@ -558,7 +619,9 @@ class DatastoreCluster(
     @sdrs_free_space_utilization_difference.setter
     def sdrs_free_space_utilization_difference(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_free_space_utilization_difference").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsFreeSpaceUtilizationDifference", value)
 
@@ -570,7 +633,9 @@ class DatastoreCluster(
     @sdrs_io_balance_automation_level.setter
     def sdrs_io_balance_automation_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_io_balance_automation_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsIoBalanceAutomationLevel", value)
 
@@ -582,7 +647,9 @@ class DatastoreCluster(
     @sdrs_io_latency_threshold.setter
     def sdrs_io_latency_threshold(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_io_latency_threshold").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsIoLatencyThreshold", value)
 
@@ -599,7 +666,9 @@ class DatastoreCluster(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_io_load_balance_enabled").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsIoLoadBalanceEnabled", value)
 
@@ -611,7 +680,9 @@ class DatastoreCluster(
     @sdrs_io_load_imbalance_threshold.setter
     def sdrs_io_load_imbalance_threshold(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_io_load_imbalance_threshold").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsIoLoadImbalanceThreshold", value)
 
@@ -623,7 +694,9 @@ class DatastoreCluster(
     @sdrs_io_reservable_iops_threshold.setter
     def sdrs_io_reservable_iops_threshold(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_io_reservable_iops_threshold").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsIoReservableIopsThreshold", value)
 
@@ -635,7 +708,9 @@ class DatastoreCluster(
     @sdrs_io_reservable_percent_threshold.setter
     def sdrs_io_reservable_percent_threshold(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_io_reservable_percent_threshold").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsIoReservablePercentThreshold", value)
 
@@ -647,7 +722,9 @@ class DatastoreCluster(
     @sdrs_io_reservable_threshold_mode.setter
     def sdrs_io_reservable_threshold_mode(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_io_reservable_threshold_mode").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsIoReservableThresholdMode", value)
 
@@ -659,7 +736,9 @@ class DatastoreCluster(
     @sdrs_load_balance_interval.setter
     def sdrs_load_balance_interval(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_load_balance_interval").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsLoadBalanceInterval", value)
 
@@ -671,7 +750,9 @@ class DatastoreCluster(
     @sdrs_policy_enforcement_automation_level.setter
     def sdrs_policy_enforcement_automation_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_policy_enforcement_automation_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsPolicyEnforcementAutomationLevel", value)
 
@@ -683,7 +764,9 @@ class DatastoreCluster(
     @sdrs_rule_enforcement_automation_level.setter
     def sdrs_rule_enforcement_automation_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_rule_enforcement_automation_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsRuleEnforcementAutomationLevel", value)
 
@@ -695,7 +778,9 @@ class DatastoreCluster(
     @sdrs_space_balance_automation_level.setter
     def sdrs_space_balance_automation_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_space_balance_automation_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsSpaceBalanceAutomationLevel", value)
 
@@ -707,7 +792,9 @@ class DatastoreCluster(
     @sdrs_space_utilization_threshold.setter
     def sdrs_space_utilization_threshold(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_space_utilization_threshold").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsSpaceUtilizationThreshold", value)
 
@@ -719,7 +806,9 @@ class DatastoreCluster(
     @sdrs_vm_evacuation_automation_level.setter
     def sdrs_vm_evacuation_automation_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "sdrs_vm_evacuation_automation_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sdrsVmEvacuationAutomationLevel", value)
 
@@ -731,7 +820,9 @@ class DatastoreCluster(
     @tags.setter
     def tags(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatastoreCluster, "tags").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
@@ -851,7 +942,44 @@ class DatastoreClusterConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DatastoreClusterConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                datacenter_id: builtins.str,
+                name: builtins.str,
+                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                folder: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                sdrs_advanced_options: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                sdrs_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_default_intra_vm_affinity: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                sdrs_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                sdrs_free_space_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_free_space_threshold_mode: typing.Optional[builtins.str] = None,
+                sdrs_free_space_utilization_difference: typing.Optional[jsii.Number] = None,
+                sdrs_io_balance_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_io_latency_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_load_balance_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                sdrs_io_load_imbalance_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_reservable_iops_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_reservable_percent_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_io_reservable_threshold_mode: typing.Optional[builtins.str] = None,
+                sdrs_load_balance_interval: typing.Optional[jsii.Number] = None,
+                sdrs_policy_enforcement_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_rule_enforcement_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_space_balance_automation_level: typing.Optional[builtins.str] = None,
+                sdrs_space_utilization_threshold: typing.Optional[jsii.Number] = None,
+                sdrs_vm_evacuation_automation_level: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
