@@ -62,7 +62,24 @@ class EntityPermissions(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EntityPermissions.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                entity_id: builtins.str,
+                entity_type: builtins.str,
+                permissions: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[EntityPermissionsPermissions, typing.Dict[str, typing.Any]]]],
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = EntityPermissionsConfig(
@@ -90,7 +107,11 @@ class EntityPermissions(
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EntityPermissions.put_permissions)
+            def stub(
+                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[EntityPermissionsPermissions, typing.Dict[str, typing.Any]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putPermissions", [value]))
 
@@ -142,7 +163,9 @@ class EntityPermissions(
     @entity_id.setter
     def entity_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissions, "entity_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "entityId", value)
 
@@ -154,7 +177,9 @@ class EntityPermissions(
     @entity_type.setter
     def entity_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissions, "entity_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "entityType", value)
 
@@ -166,7 +191,9 @@ class EntityPermissions(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissions, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -220,7 +247,22 @@ class EntityPermissionsConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(EntityPermissionsConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                entity_id: builtins.str,
+                entity_type: builtins.str,
+                permissions: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[EntityPermissionsPermissions, typing.Dict[str, typing.Any]]]],
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -394,7 +436,15 @@ class EntityPermissionsPermissions:
         :param user_or_group: User or group receiving access. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/entity_permissions#user_or_group EntityPermissions#user_or_group}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EntityPermissionsPermissions.__init__)
+            def stub(
+                *,
+                is_group: typing.Union[builtins.bool, cdktf.IResolvable],
+                propagate: typing.Union[builtins.bool, cdktf.IResolvable],
+                role_id: builtins.str,
+                user_or_group: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument is_group", value=is_group, expected_type=type_hints["is_group"])
             check_type(argname="argument propagate", value=propagate, expected_type=type_hints["propagate"])
             check_type(argname="argument role_id", value=role_id, expected_type=type_hints["role_id"])
@@ -475,7 +525,13 @@ class EntityPermissionsPermissionsList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EntityPermissionsPermissionsList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -487,7 +543,9 @@ class EntityPermissionsPermissionsList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EntityPermissionsPermissionsList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("EntityPermissionsPermissionsOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -500,7 +558,9 @@ class EntityPermissionsPermissionsList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -513,7 +573,9 @@ class EntityPermissionsPermissionsList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -526,7 +588,9 @@ class EntityPermissionsPermissionsList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -543,7 +607,11 @@ class EntityPermissionsPermissionsList(
         value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[EntityPermissionsPermissions]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsList, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[EntityPermissionsPermissions]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -567,7 +635,14 @@ class EntityPermissionsPermissionsOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EntityPermissionsPermissionsOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -606,7 +681,9 @@ class EntityPermissionsPermissionsOutputReference(
     @is_group.setter
     def is_group(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsOutputReference, "is_group").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isGroup", value)
 
@@ -618,7 +695,9 @@ class EntityPermissionsPermissionsOutputReference(
     @propagate.setter
     def propagate(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsOutputReference, "propagate").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "propagate", value)
 
@@ -630,7 +709,9 @@ class EntityPermissionsPermissionsOutputReference(
     @role_id.setter
     def role_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsOutputReference, "role_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "roleId", value)
 
@@ -642,7 +723,9 @@ class EntityPermissionsPermissionsOutputReference(
     @user_or_group.setter
     def user_or_group(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsOutputReference, "user_or_group").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "userOrGroup", value)
 
@@ -659,7 +742,11 @@ class EntityPermissionsPermissionsOutputReference(
         value: typing.Optional[typing.Union[EntityPermissionsPermissions, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(EntityPermissionsPermissionsOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[EntityPermissionsPermissions, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
