@@ -86,7 +86,36 @@ class HaVmOverride(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HaVmOverride.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                compute_cluster_id: builtins.str,
+                virtual_machine_id: builtins.str,
+                ha_datastore_apd_recovery_action: typing.Optional[builtins.str] = None,
+                ha_datastore_apd_response: typing.Optional[builtins.str] = None,
+                ha_datastore_apd_response_delay: typing.Optional[jsii.Number] = None,
+                ha_datastore_pdl_response: typing.Optional[builtins.str] = None,
+                ha_host_isolation_response: typing.Optional[builtins.str] = None,
+                ha_vm_failure_interval: typing.Optional[jsii.Number] = None,
+                ha_vm_maximum_failure_window: typing.Optional[jsii.Number] = None,
+                ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
+                ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
+                ha_vm_monitoring: typing.Optional[builtins.str] = None,
+                ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                ha_vm_restart_priority: typing.Optional[builtins.str] = None,
+                ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = HaVmOverrideConfig(
@@ -272,7 +301,9 @@ class HaVmOverride(
     @compute_cluster_id.setter
     def compute_cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "compute_cluster_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computeClusterId", value)
 
@@ -284,7 +315,9 @@ class HaVmOverride(
     @ha_datastore_apd_recovery_action.setter
     def ha_datastore_apd_recovery_action(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_datastore_apd_recovery_action").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastoreApdRecoveryAction", value)
 
@@ -296,7 +329,9 @@ class HaVmOverride(
     @ha_datastore_apd_response.setter
     def ha_datastore_apd_response(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_datastore_apd_response").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastoreApdResponse", value)
 
@@ -308,7 +343,9 @@ class HaVmOverride(
     @ha_datastore_apd_response_delay.setter
     def ha_datastore_apd_response_delay(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_datastore_apd_response_delay").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastoreApdResponseDelay", value)
 
@@ -320,7 +357,9 @@ class HaVmOverride(
     @ha_datastore_pdl_response.setter
     def ha_datastore_pdl_response(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_datastore_pdl_response").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastorePdlResponse", value)
 
@@ -332,7 +371,9 @@ class HaVmOverride(
     @ha_host_isolation_response.setter
     def ha_host_isolation_response(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_host_isolation_response").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haHostIsolationResponse", value)
 
@@ -344,7 +385,9 @@ class HaVmOverride(
     @ha_vm_failure_interval.setter
     def ha_vm_failure_interval(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_failure_interval").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmFailureInterval", value)
 
@@ -356,7 +399,9 @@ class HaVmOverride(
     @ha_vm_maximum_failure_window.setter
     def ha_vm_maximum_failure_window(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_maximum_failure_window").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMaximumFailureWindow", value)
 
@@ -368,7 +413,9 @@ class HaVmOverride(
     @ha_vm_maximum_resets.setter
     def ha_vm_maximum_resets(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_maximum_resets").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMaximumResets", value)
 
@@ -380,7 +427,9 @@ class HaVmOverride(
     @ha_vm_minimum_uptime.setter
     def ha_vm_minimum_uptime(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_minimum_uptime").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMinimumUptime", value)
 
@@ -392,7 +441,9 @@ class HaVmOverride(
     @ha_vm_monitoring.setter
     def ha_vm_monitoring(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_monitoring").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMonitoring", value)
 
@@ -409,7 +460,9 @@ class HaVmOverride(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_monitoring_use_cluster_defaults").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMonitoringUseClusterDefaults", value)
 
@@ -421,7 +474,9 @@ class HaVmOverride(
     @ha_vm_restart_priority.setter
     def ha_vm_restart_priority(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_restart_priority").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmRestartPriority", value)
 
@@ -433,7 +488,9 @@ class HaVmOverride(
     @ha_vm_restart_timeout.setter
     def ha_vm_restart_timeout(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "ha_vm_restart_timeout").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmRestartTimeout", value)
 
@@ -445,7 +502,9 @@ class HaVmOverride(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -457,7 +516,9 @@ class HaVmOverride(
     @virtual_machine_id.setter
     def virtual_machine_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HaVmOverride, "virtual_machine_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "virtualMachineId", value)
 
@@ -547,7 +608,34 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(HaVmOverrideConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                compute_cluster_id: builtins.str,
+                virtual_machine_id: builtins.str,
+                ha_datastore_apd_recovery_action: typing.Optional[builtins.str] = None,
+                ha_datastore_apd_response: typing.Optional[builtins.str] = None,
+                ha_datastore_apd_response_delay: typing.Optional[jsii.Number] = None,
+                ha_datastore_pdl_response: typing.Optional[builtins.str] = None,
+                ha_host_isolation_response: typing.Optional[builtins.str] = None,
+                ha_vm_failure_interval: typing.Optional[jsii.Number] = None,
+                ha_vm_maximum_failure_window: typing.Optional[jsii.Number] = None,
+                ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
+                ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
+                ha_vm_monitoring: typing.Optional[builtins.str] = None,
+                ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                ha_vm_restart_priority: typing.Optional[builtins.str] = None,
+                ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
