@@ -98,7 +98,42 @@ class HostVirtualSwitch(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HostVirtualSwitch.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                active_nics: typing.Sequence[builtins.str],
+                host_system_id: builtins.str,
+                name: builtins.str,
+                network_adapters: typing.Sequence[builtins.str],
+                standby_nics: typing.Sequence[builtins.str],
+                allow_forged_transmits: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                allow_mac_changes: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                allow_promiscuous: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                beacon_interval: typing.Optional[jsii.Number] = None,
+                check_beacon: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                failback: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                link_discovery_operation: typing.Optional[builtins.str] = None,
+                link_discovery_protocol: typing.Optional[builtins.str] = None,
+                mtu: typing.Optional[jsii.Number] = None,
+                notify_switches: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                number_of_ports: typing.Optional[jsii.Number] = None,
+                shaping_average_bandwidth: typing.Optional[jsii.Number] = None,
+                shaping_burst_size: typing.Optional[jsii.Number] = None,
+                shaping_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                shaping_peak_bandwidth: typing.Optional[jsii.Number] = None,
+                teaming_policy: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = HostVirtualSwitchConfig(
@@ -344,7 +379,9 @@ class HostVirtualSwitch(
     @active_nics.setter
     def active_nics(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "active_nics").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "activeNics", value)
 
@@ -359,7 +396,9 @@ class HostVirtualSwitch(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "allow_forged_transmits").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowForgedTransmits", value)
 
@@ -374,7 +413,9 @@ class HostVirtualSwitch(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "allow_mac_changes").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowMacChanges", value)
 
@@ -389,7 +430,9 @@ class HostVirtualSwitch(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "allow_promiscuous").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowPromiscuous", value)
 
@@ -401,7 +444,9 @@ class HostVirtualSwitch(
     @beacon_interval.setter
     def beacon_interval(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "beacon_interval").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "beaconInterval", value)
 
@@ -416,7 +461,9 @@ class HostVirtualSwitch(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "check_beacon").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "checkBeacon", value)
 
@@ -428,7 +475,9 @@ class HostVirtualSwitch(
     @failback.setter
     def failback(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "failback").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "failback", value)
 
@@ -440,7 +489,9 @@ class HostVirtualSwitch(
     @host_system_id.setter
     def host_system_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "host_system_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "hostSystemId", value)
 
@@ -452,7 +503,9 @@ class HostVirtualSwitch(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -464,7 +517,9 @@ class HostVirtualSwitch(
     @link_discovery_operation.setter
     def link_discovery_operation(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "link_discovery_operation").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "linkDiscoveryOperation", value)
 
@@ -476,7 +531,9 @@ class HostVirtualSwitch(
     @link_discovery_protocol.setter
     def link_discovery_protocol(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "link_discovery_protocol").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "linkDiscoveryProtocol", value)
 
@@ -488,7 +545,9 @@ class HostVirtualSwitch(
     @mtu.setter
     def mtu(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "mtu").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mtu", value)
 
@@ -500,7 +559,9 @@ class HostVirtualSwitch(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -512,7 +573,9 @@ class HostVirtualSwitch(
     @network_adapters.setter
     def network_adapters(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "network_adapters").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "networkAdapters", value)
 
@@ -527,7 +590,9 @@ class HostVirtualSwitch(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "notify_switches").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "notifySwitches", value)
 
@@ -539,7 +604,9 @@ class HostVirtualSwitch(
     @number_of_ports.setter
     def number_of_ports(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "number_of_ports").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "numberOfPorts", value)
 
@@ -551,7 +618,9 @@ class HostVirtualSwitch(
     @shaping_average_bandwidth.setter
     def shaping_average_bandwidth(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "shaping_average_bandwidth").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "shapingAverageBandwidth", value)
 
@@ -563,7 +632,9 @@ class HostVirtualSwitch(
     @shaping_burst_size.setter
     def shaping_burst_size(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "shaping_burst_size").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "shapingBurstSize", value)
 
@@ -578,7 +649,9 @@ class HostVirtualSwitch(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "shaping_enabled").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "shapingEnabled", value)
 
@@ -590,7 +663,9 @@ class HostVirtualSwitch(
     @shaping_peak_bandwidth.setter
     def shaping_peak_bandwidth(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "shaping_peak_bandwidth").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "shapingPeakBandwidth", value)
 
@@ -602,7 +677,9 @@ class HostVirtualSwitch(
     @standby_nics.setter
     def standby_nics(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "standby_nics").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "standbyNics", value)
 
@@ -614,7 +691,9 @@ class HostVirtualSwitch(
     @teaming_policy.setter
     def teaming_policy(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostVirtualSwitch, "teaming_policy").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "teamingPolicy", value)
 
@@ -722,7 +801,40 @@ class HostVirtualSwitchConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(HostVirtualSwitchConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                active_nics: typing.Sequence[builtins.str],
+                host_system_id: builtins.str,
+                name: builtins.str,
+                network_adapters: typing.Sequence[builtins.str],
+                standby_nics: typing.Sequence[builtins.str],
+                allow_forged_transmits: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                allow_mac_changes: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                allow_promiscuous: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                beacon_interval: typing.Optional[jsii.Number] = None,
+                check_beacon: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                failback: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                link_discovery_operation: typing.Optional[builtins.str] = None,
+                link_discovery_protocol: typing.Optional[builtins.str] = None,
+                mtu: typing.Optional[jsii.Number] = None,
+                notify_switches: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                number_of_ports: typing.Optional[jsii.Number] = None,
+                shaping_average_bandwidth: typing.Optional[jsii.Number] = None,
+                shaping_burst_size: typing.Optional[jsii.Number] = None,
+                shaping_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                shaping_peak_bandwidth: typing.Optional[jsii.Number] = None,
+                teaming_policy: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
