@@ -68,7 +68,27 @@ class VsphereProvider(
         :param vsphere_server: The vSphere Server name for vSphere API operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere#vsphere_server VsphereProvider#vsphere_server}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VsphereProvider.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                password: builtins.str,
+                user: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                api_timeout: typing.Optional[jsii.Number] = None,
+                client_debug: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                client_debug_path: typing.Optional[builtins.str] = None,
+                client_debug_path_run: typing.Optional[builtins.str] = None,
+                persist_session: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                rest_session_path: typing.Optional[builtins.str] = None,
+                vcenter_server: typing.Optional[builtins.str] = None,
+                vim_keep_alive: typing.Optional[jsii.Number] = None,
+                vim_session_path: typing.Optional[builtins.str] = None,
+                vsphere_server: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = VsphereProviderConfig(
@@ -231,7 +251,9 @@ class VsphereProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "alias").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -248,7 +270,11 @@ class VsphereProvider(
         value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "allow_unverified_ssl").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowUnverifiedSsl", value)
 
@@ -260,7 +286,9 @@ class VsphereProvider(
     @api_timeout.setter
     def api_timeout(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "api_timeout").fset)
+            def stub(value: typing.Optional[jsii.Number]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "apiTimeout", value)
 
@@ -277,7 +305,11 @@ class VsphereProvider(
         value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "client_debug").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientDebug", value)
 
@@ -289,7 +321,9 @@ class VsphereProvider(
     @client_debug_path.setter
     def client_debug_path(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "client_debug_path").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientDebugPath", value)
 
@@ -301,7 +335,9 @@ class VsphereProvider(
     @client_debug_path_run.setter
     def client_debug_path_run(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "client_debug_path_run").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientDebugPathRun", value)
 
@@ -313,7 +349,9 @@ class VsphereProvider(
     @password.setter
     def password(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "password").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -330,7 +368,11 @@ class VsphereProvider(
         value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "persist_session").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "persistSession", value)
 
@@ -342,7 +384,9 @@ class VsphereProvider(
     @rest_session_path.setter
     def rest_session_path(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "rest_session_path").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "restSessionPath", value)
 
@@ -354,7 +398,9 @@ class VsphereProvider(
     @user.setter
     def user(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "user").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "user", value)
 
@@ -366,7 +412,9 @@ class VsphereProvider(
     @vcenter_server.setter
     def vcenter_server(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "vcenter_server").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vcenterServer", value)
 
@@ -378,7 +426,9 @@ class VsphereProvider(
     @vim_keep_alive.setter
     def vim_keep_alive(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "vim_keep_alive").fset)
+            def stub(value: typing.Optional[jsii.Number]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vimKeepAlive", value)
 
@@ -390,7 +440,9 @@ class VsphereProvider(
     @vim_session_path.setter
     def vim_session_path(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "vim_session_path").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vimSessionPath", value)
 
@@ -402,7 +454,9 @@ class VsphereProvider(
     @vsphere_server.setter
     def vsphere_server(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VsphereProvider, "vsphere_server").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vsphereServer", value)
 
@@ -463,7 +517,25 @@ class VsphereProviderConfig:
         :param vsphere_server: The vSphere Server name for vSphere API operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere#vsphere_server VsphereProvider#vsphere_server}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VsphereProviderConfig.__init__)
+            def stub(
+                *,
+                password: builtins.str,
+                user: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                api_timeout: typing.Optional[jsii.Number] = None,
+                client_debug: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                client_debug_path: typing.Optional[builtins.str] = None,
+                client_debug_path_run: typing.Optional[builtins.str] = None,
+                persist_session: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                rest_session_path: typing.Optional[builtins.str] = None,
+                vcenter_server: typing.Optional[builtins.str] = None,
+                vim_keep_alive: typing.Optional[jsii.Number] = None,
+                vim_session_path: typing.Optional[builtins.str] = None,
+                vsphere_server: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument password", value=password, expected_type=type_hints["password"])
             check_type(argname="argument user", value=user, expected_type=type_hints["user"])
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
