@@ -86,7 +86,36 @@ class VappContainer(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VappContainer.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                name: builtins.str,
+                parent_resource_pool_id: builtins.str,
+                cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                cpu_limit: typing.Optional[jsii.Number] = None,
+                cpu_reservation: typing.Optional[jsii.Number] = None,
+                cpu_share_level: typing.Optional[builtins.str] = None,
+                cpu_shares: typing.Optional[jsii.Number] = None,
+                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                id: typing.Optional[builtins.str] = None,
+                memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                memory_limit: typing.Optional[jsii.Number] = None,
+                memory_reservation: typing.Optional[jsii.Number] = None,
+                memory_share_level: typing.Optional[builtins.str] = None,
+                memory_shares: typing.Optional[jsii.Number] = None,
+                parent_folder_id: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = VappContainerConfig(
@@ -279,7 +308,9 @@ class VappContainer(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "cpu_expandable").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuExpandable", value)
 
@@ -291,7 +322,9 @@ class VappContainer(
     @cpu_limit.setter
     def cpu_limit(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "cpu_limit").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuLimit", value)
 
@@ -303,7 +336,9 @@ class VappContainer(
     @cpu_reservation.setter
     def cpu_reservation(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "cpu_reservation").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuReservation", value)
 
@@ -315,7 +350,9 @@ class VappContainer(
     @cpu_share_level.setter
     def cpu_share_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "cpu_share_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuShareLevel", value)
 
@@ -327,7 +364,9 @@ class VappContainer(
     @cpu_shares.setter
     def cpu_shares(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "cpu_shares").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuShares", value)
 
@@ -342,7 +381,9 @@ class VappContainer(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "custom_attributes").fset)
+            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "customAttributes", value)
 
@@ -354,7 +395,9 @@ class VappContainer(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -369,7 +412,9 @@ class VappContainer(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "memory_expandable").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryExpandable", value)
 
@@ -381,7 +426,9 @@ class VappContainer(
     @memory_limit.setter
     def memory_limit(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "memory_limit").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryLimit", value)
 
@@ -393,7 +440,9 @@ class VappContainer(
     @memory_reservation.setter
     def memory_reservation(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "memory_reservation").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryReservation", value)
 
@@ -405,7 +454,9 @@ class VappContainer(
     @memory_share_level.setter
     def memory_share_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "memory_share_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryShareLevel", value)
 
@@ -417,7 +468,9 @@ class VappContainer(
     @memory_shares.setter
     def memory_shares(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "memory_shares").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryShares", value)
 
@@ -429,7 +482,9 @@ class VappContainer(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -441,7 +496,9 @@ class VappContainer(
     @parent_folder_id.setter
     def parent_folder_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "parent_folder_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "parentFolderId", value)
 
@@ -453,7 +510,9 @@ class VappContainer(
     @parent_resource_pool_id.setter
     def parent_resource_pool_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "parent_resource_pool_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "parentResourcePoolId", value)
 
@@ -465,7 +524,9 @@ class VappContainer(
     @tags.setter
     def tags(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappContainer, "tags").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
@@ -555,7 +616,34 @@ class VappContainerConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(VappContainerConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                name: builtins.str,
+                parent_resource_pool_id: builtins.str,
+                cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                cpu_limit: typing.Optional[jsii.Number] = None,
+                cpu_reservation: typing.Optional[jsii.Number] = None,
+                cpu_share_level: typing.Optional[builtins.str] = None,
+                cpu_shares: typing.Optional[jsii.Number] = None,
+                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                id: typing.Optional[builtins.str] = None,
+                memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                memory_limit: typing.Optional[jsii.Number] = None,
+                memory_reservation: typing.Optional[jsii.Number] = None,
+                memory_share_level: typing.Optional[builtins.str] = None,
+                memory_shares: typing.Optional[jsii.Number] = None,
+                parent_folder_id: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
