@@ -76,7 +76,31 @@ class VappEntity(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VappEntity.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                container_id: builtins.str,
+                target_id: builtins.str,
+                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                id: typing.Optional[builtins.str] = None,
+                start_action: typing.Optional[builtins.str] = None,
+                start_delay: typing.Optional[jsii.Number] = None,
+                start_order: typing.Optional[jsii.Number] = None,
+                stop_action: typing.Optional[builtins.str] = None,
+                stop_delay: typing.Optional[jsii.Number] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                wait_for_guest: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = VappEntityConfig(
@@ -214,7 +238,9 @@ class VappEntity(
     @container_id.setter
     def container_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "container_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "containerId", value)
 
@@ -229,7 +255,9 @@ class VappEntity(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "custom_attributes").fset)
+            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "customAttributes", value)
 
@@ -241,7 +269,9 @@ class VappEntity(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -253,7 +283,9 @@ class VappEntity(
     @start_action.setter
     def start_action(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "start_action").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "startAction", value)
 
@@ -265,7 +297,9 @@ class VappEntity(
     @start_delay.setter
     def start_delay(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "start_delay").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "startDelay", value)
 
@@ -277,7 +311,9 @@ class VappEntity(
     @start_order.setter
     def start_order(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "start_order").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "startOrder", value)
 
@@ -289,7 +325,9 @@ class VappEntity(
     @stop_action.setter
     def stop_action(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "stop_action").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "stopAction", value)
 
@@ -301,7 +339,9 @@ class VappEntity(
     @stop_delay.setter
     def stop_delay(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "stop_delay").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "stopDelay", value)
 
@@ -313,7 +353,9 @@ class VappEntity(
     @tags.setter
     def tags(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "tags").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
@@ -325,7 +367,9 @@ class VappEntity(
     @target_id.setter
     def target_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "target_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetId", value)
 
@@ -340,7 +384,9 @@ class VappEntity(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VappEntity, "wait_for_guest").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "waitForGuest", value)
 
@@ -415,7 +461,29 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(VappEntityConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                container_id: builtins.str,
+                target_id: builtins.str,
+                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                id: typing.Optional[builtins.str] = None,
+                start_action: typing.Optional[builtins.str] = None,
+                start_delay: typing.Optional[jsii.Number] = None,
+                start_order: typing.Optional[jsii.Number] = None,
+                stop_action: typing.Optional[builtins.str] = None,
+                stop_delay: typing.Optional[jsii.Number] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                wait_for_guest: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
