@@ -74,7 +74,30 @@ class Vnic(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Vnic.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                host: builtins.str,
+                distributed_port_group: typing.Optional[builtins.str] = None,
+                distributed_switch_port: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                ipv4: typing.Optional[typing.Union[VnicIpv4, typing.Dict[str, typing.Any]]] = None,
+                ipv6: typing.Optional[typing.Union[VnicIpv6, typing.Dict[str, typing.Any]]] = None,
+                mac: typing.Optional[builtins.str] = None,
+                mtu: typing.Optional[jsii.Number] = None,
+                netstack: typing.Optional[builtins.str] = None,
+                portgroup: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = VnicConfig(
@@ -250,7 +273,9 @@ class Vnic(
     @distributed_port_group.setter
     def distributed_port_group(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "distributed_port_group").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "distributedPortGroup", value)
 
@@ -262,7 +287,9 @@ class Vnic(
     @distributed_switch_port.setter
     def distributed_switch_port(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "distributed_switch_port").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "distributedSwitchPort", value)
 
@@ -274,7 +301,9 @@ class Vnic(
     @host.setter
     def host(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "host").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "host", value)
 
@@ -286,7 +315,9 @@ class Vnic(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -298,7 +329,9 @@ class Vnic(
     @mac.setter
     def mac(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "mac").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mac", value)
 
@@ -310,7 +343,9 @@ class Vnic(
     @mtu.setter
     def mtu(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "mtu").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mtu", value)
 
@@ -322,7 +357,9 @@ class Vnic(
     @netstack.setter
     def netstack(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "netstack").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "netstack", value)
 
@@ -334,7 +371,9 @@ class Vnic(
     @portgroup.setter
     def portgroup(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Vnic, "portgroup").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "portgroup", value)
 
@@ -410,7 +449,28 @@ class VnicConfig(cdktf.TerraformMetaArguments):
         if isinstance(ipv6, dict):
             ipv6 = VnicIpv6(**ipv6)
         if __debug__:
-            type_hints = typing.get_type_hints(VnicConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                host: builtins.str,
+                distributed_port_group: typing.Optional[builtins.str] = None,
+                distributed_switch_port: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                ipv4: typing.Optional[typing.Union[VnicIpv4, typing.Dict[str, typing.Any]]] = None,
+                ipv6: typing.Optional[typing.Union[VnicIpv6, typing.Dict[str, typing.Any]]] = None,
+                mac: typing.Optional[builtins.str] = None,
+                mtu: typing.Optional[jsii.Number] = None,
+                netstack: typing.Optional[builtins.str] = None,
+                portgroup: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -649,7 +709,15 @@ class VnicIpv4:
         :param netmask: netmask of the interface, if DHCP is not set. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/vnic#netmask Vnic#netmask}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VnicIpv4.__init__)
+            def stub(
+                *,
+                dhcp: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                gw: typing.Optional[builtins.str] = None,
+                ip: typing.Optional[builtins.str] = None,
+                netmask: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument dhcp", value=dhcp, expected_type=type_hints["dhcp"])
             check_type(argname="argument gw", value=gw, expected_type=type_hints["gw"])
             check_type(argname="argument ip", value=ip, expected_type=type_hints["ip"])
@@ -727,7 +795,12 @@ class VnicIpv4OutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VnicIpv4OutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -778,7 +851,9 @@ class VnicIpv4OutputReference(
     @dhcp.setter
     def dhcp(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv4OutputReference, "dhcp").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dhcp", value)
 
@@ -790,7 +865,9 @@ class VnicIpv4OutputReference(
     @gw.setter
     def gw(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv4OutputReference, "gw").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "gw", value)
 
@@ -802,7 +879,9 @@ class VnicIpv4OutputReference(
     @ip.setter
     def ip(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv4OutputReference, "ip").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ip", value)
 
@@ -814,7 +893,9 @@ class VnicIpv4OutputReference(
     @netmask.setter
     def netmask(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv4OutputReference, "netmask").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "netmask", value)
 
@@ -826,7 +907,9 @@ class VnicIpv4OutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[VnicIpv4]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv4OutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[VnicIpv4]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -857,7 +940,15 @@ class VnicIpv6:
         :param gw: IP address of the default gateway, if DHCP or autoconfig is not set. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/vnic#gw Vnic#gw}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VnicIpv6.__init__)
+            def stub(
+                *,
+                addresses: typing.Optional[typing.Sequence[builtins.str]] = None,
+                autoconfig: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                dhcp: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                gw: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument addresses", value=addresses, expected_type=type_hints["addresses"])
             check_type(argname="argument autoconfig", value=autoconfig, expected_type=type_hints["autoconfig"])
             check_type(argname="argument dhcp", value=dhcp, expected_type=type_hints["dhcp"])
@@ -937,7 +1028,12 @@ class VnicIpv6OutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(VnicIpv6OutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -990,7 +1086,9 @@ class VnicIpv6OutputReference(
     @addresses.setter
     def addresses(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv6OutputReference, "addresses").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "addresses", value)
 
@@ -1002,7 +1100,9 @@ class VnicIpv6OutputReference(
     @autoconfig.setter
     def autoconfig(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv6OutputReference, "autoconfig").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "autoconfig", value)
 
@@ -1014,7 +1114,9 @@ class VnicIpv6OutputReference(
     @dhcp.setter
     def dhcp(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv6OutputReference, "dhcp").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "dhcp", value)
 
@@ -1026,7 +1128,9 @@ class VnicIpv6OutputReference(
     @gw.setter
     def gw(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv6OutputReference, "gw").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "gw", value)
 
@@ -1038,7 +1142,9 @@ class VnicIpv6OutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[VnicIpv6]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(VnicIpv6OutputReference, "internal_value").fset)
+            def stub(value: typing.Optional[VnicIpv6]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
